#
# spec file for package python-pysmbc
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         oldpython python
# Tests don't work in rpmbuild sandbox
%bcond_with     test
Name:           python-pysmbc
Version:        1.0.15.8
Release:        lp151.2.2
Summary:        Python bindings for samba clients (libsmbclient)
License:        GPL-2.0+
Group:          Development/Languages/Python
Url:            http://cyberelk.net/tim/software/pysmbc/
Source:         https://files.pythonhosted.org/packages/source/p/pysmbc/pysmbc-%{version}.tar.bz2
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  libsmbclient-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module nose}
%endif
%ifpython2
Obsoletes:      %{oldpython}-smbc < %{version}
Provides:       %{oldpython}-smbc = %{version}
%endif
%ifpython3
Obsoletes:      python3-smbc < %{version}
Provides:       python3-smbc = %{version}
%endif

%python_subpackages

%description
This is a set of Python bindings for the libsmbclient library
from the samba project.

%prep
%setup -q -n pysmbc-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install

%{python_expand chmod a+x %{buildroot}%{$python_sitearch}/smbc/xattr.py
sed -i "s|^#!/usr/bin/python$|#!%__$python|" %{buildroot}%{$python_sitearch}/smbc/xattr.py
$python -m compileall -d %{$python_sitearch} %{buildroot}%{$python_sitearch}/smbc/
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitearch}/smbc/
%fdupes %{buildroot}%{$python_sitearch}
}

%if %{with test}
%check
pushd tests
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
$python -B -m nose .
}
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc COPYING NEWS
%{python_sitearch}/*

%changelog
* Thu Sep  7 2017 toddrme2178@gmail.com
- Rename to python-pysmbc to follow python package naming rules.
- Update to version 1.0.15.8
  * No changelog
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Sat Sep  3 2016 p.drouand@gmail.com
- Fix Url
* Fri Jan 15 2016 termim@gmail.com
- Remove python-smbc-pkg-config.patch - applied upstream
- Remove pre_checking.sh - no need to copy python files to python3
- Update to version 1.0.15.5:
  * fix NUL-termination bug
- Update to version 1.0.15.4:
  * added some constants
- Update to version 1.0.15.3:
  * added smbc.ConnectionRefusedError
- Update to version 1.0.15.1:
  * Return direntry with unicode string
- Update to version 1.0.15:
  * Working with Python3
- Update to version 1.0.14.2:
  * added smbc.NotDirectoryError
- Update to version 1.0.14.1:
  * Fix for Python 2.6
- Update to version 1.0.14:
  * Context.set_credentials_with_fallback()
  * Context.getxattr, Context.setxattr
  * smbc.XATTR, smbc.XATTR_ACL, smbc.XATTR_ACL_SID, smbc.XATTR_ALL,
    smbc.XATTR_ALL_SID, smbc.XATTR_FLAG_CREATE, smbc.XATTR_FLAG_REPLACE,
    smbc.XATTR_GROUP, smbc.XATTR_GROUP_SID, smbc.XATTR_OWNER,
    smbc.XATTR_OWNER_SID, smbc.XATTR_REVISION
* Mon Jun  2 2014 dvaleev@suse.com
- Add pkgconfig to BuildRequires to fix build
* Mon Sep  2 2013 zaitor@opensuse.org
- Add python-smbc-pkg-config.patch, fixes build with samba 4.
* Tue Jan 15 2013 p.drouand@gmail.com
- Initial python3 support
* Wed Feb 15 2012 dimstar@opensuse.org
- Update to version 1.0.13:
  + Call initial libsmbclient functions in right order.
  + Memory/connection leaks.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 1.0.12:
  + Add Context.optionUseKerberos
  + Add Context.optionFallbackAfterKerberos
* Fri May 27 2011 vuntz@opensuse.org
- Update to version 1.0.11:
  + read/iternext now use Bytes type
* Wed Nov 10 2010 vuntz@opensuse.org
- Update to version 1.0.10:
  + smbc.NoSpaceError
  + Now buildable against Python 3
* Mon Sep  6 2010 coolo@novell.com
- Fix build with python 2.7, by fixing a filename in the file list.
* Mon Aug 23 2010 dimstar@opensuse.org
- Update to version 1.0.9:
  + iteration file read
  + rewrite tests for python nose
  + fixed stat portability issue
  + smbc.NoEntryError
  + smbc.ExistsError
  + smbc.NotEmptyError
  + smbc.TimedOutError
  + File.seek() and File.lseek()
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 1.0.8:
  + Context.chmod()
  + Context.rename()
  + Context.unlink()
  + Context.creat()
- Changes from version 1.0.7:
  + Context.open: omissible flags and mode
  + File: omissible flags and mode
  + File.read()
  + smbc.PermissionError
  + Context.mkdir()
  + Context.stat()
  + File.fstat()
  + File.write()
  + File.close()
* Sat Feb 21 2009 vuntz@novell.com
- Split from system-config-printer.
